@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 my %introduces = ( 5.024 => [qw[
                                  unicode8.0 \b{lb} sprintf-reorder
@@ -51,7 +51,7 @@ my %introduced = map {
 sub _hook {
     { drand48 => sub {
           require Config;
-          warn "Incompatible rand implementation at ", _position(1), "\n"
+          warn "Unknown rand implementation at ", _position(1), "\n"
               unless 'Perl_drand48' eq $Config::Config{randfunc};
       },
     }
@@ -119,7 +119,7 @@ Syntax::Construct - Identify which non-feature constructs are used in the code.
 
 =head1 VERSION
 
-Version 0.26
+Version 0.27
 
 =head1 SYNOPSIS
 
